@@ -29,11 +29,11 @@ ee_pin_type_to_ki_pin_type = {
 }
 
 
-def px_to_mil(dim: int) -> int:
-    return 10 * dim
+def px_to_mil(dim: Union[int, float]) -> int:
+    return int(10 * dim)
 
 
-def px_to_mm(dim: int) -> float:
+def px_to_mm(dim: Union[int, float]) -> float:
     return 10.0 * dim * 0.0254
 
 
@@ -42,18 +42,21 @@ def convert_ee_pins(
 ) -> List[KiSymbolPin]:
 
     to_ki: Callable = px_to_mil if kicad_version == KicadVersion.v5 else px_to_mm
-    pin_spacing = (
-        KiExportConfigV5.PIN_SPACING.value
-        if kicad_version == KicadVersion.v5
-        else KiExportConfigV6.PIN_SPACING.value
-    )
+    # pin_spacing = (
+    #     KiExportConfigV5.PIN_SPACING.value
+    #     if kicad_version == KicadVersion.v5
+    #     else KiExportConfigV6.PIN_SPACING.value
+    # )
 
     kicad_pins = []
     for ee_pin in ee_pins:
+        pin_length = abs(int(float(ee_pin.pin_path.path.split("h")[-1])))
+
         ki_pin = KiSymbolPin(
             name=ee_pin.name.text.replace(" ", ""),
             number=ee_pin.settings.spice_pin_number.replace(" ", ""),
             style=KiPinStyle.line,
+            length=to_ki(pin_length),
             type=ee_pin_type_to_ki_pin_type[ee_pin.settings.type],
             orientation=ee_pin.settings.rotation,
             pos_x=to_ki(int(ee_pin.settings.pos_x) - int(ee_bbox.x)),
@@ -67,16 +70,15 @@ def convert_ee_pins(
         elif ee_pin.clock.is_displayed:
             ki_pin.style = KiPinStyle.clock
 
-        pin_length = abs(int(float(ee_pin.pin_path.path.split("h")[-1])))
         # Deal with different pin length
-        if ee_pin.settings.rotation == 0:
-            ki_pin.pos_x -= to_ki(pin_length) - pin_spacing
-        elif ee_pin.settings.rotation == 180:
-            ki_pin.pos_x += to_ki(pin_length) - pin_spacing
-        elif ee_pin.settings.rotation == 90:
-            ki_pin.pos_y -= to_ki(pin_length) - pin_spacing
-        elif ee_pin.settings.rotation == 270:
-            ki_pin.pos_y += to_ki(pin_length) - pin_spacing
+        # if ee_pin.settings.rotation == 0:
+        #     ki_pin.pos_x -= to_ki(pin_length) - pin_spacing
+        # elif ee_pin.settings.rotation == 180:
+        #     ki_pin.pos_x += to_ki(pin_length) - pin_spacing
+        # elif ee_pin.settings.rotation == 90:
+        #     ki_pin.pos_y -= to_ki(pin_length) - pin_spacing
+        # elif ee_pin.settings.rotation == 270:
+        #     ki_pin.pos_y += to_ki(pin_length) - pin_spacing
 
         kicad_pins.append(ki_pin)
 
@@ -298,7 +300,7 @@ def convert_to_kicad(ee_symbol: EeSymbol, kicad_version: KicadVersion) -> KiSymb
 
     ki_info = KiSymbolInfo(
         name=ee_symbol.info.name,
-        prefix=ee_symbol.info.prefix,
+        prefix=ee_symbol.info.prefix.replace("?", ""),
         package=ee_symbol.info.package,
         manufacturer=ee_symbol.info.manufacturer,
         datasheet=ee_symbol.info.datasheet,
@@ -348,12 +350,8 @@ def convert_to_kicad(ee_symbol: EeSymbol, kicad_version: KicadVersion) -> KiSymb
     return kicad_symbol
 
 
-def tune_footprint_ref_path(
-    ki_symbol: KiSymbol, is_project_relative: bool, footprint_lib_name: str
-):
+def tune_footprint_ref_path(ki_symbol: KiSymbol, footprint_lib_name: str):
     ki_symbol.info.package = f"{footprint_lib_name}:{ki_symbol.info.package}"
-    if is_project_relative:
-        ki_symbol.info.package = "${KIPRJMOD}:" + ki_symbol.info.package
 
 
 class ExporterSymbolKicad:
@@ -366,10 +364,10 @@ class ExporterSymbolKicad:
             else logging.error("Unknown input symbol format")
         )
 
-    def export(self, is_project_relative: bool, footprint_lib_name: str) -> str:
+    def export(self, footprint_lib_name: str) -> str:
+
         tune_footprint_ref_path(
             ki_symbol=self.output,
-            is_project_relative=is_project_relative,
             footprint_lib_name=footprint_lib_name,
         )
         return self.output.export(kicad_version=self.version)
